CompositeDefect class final
Preserves a primary defect together with another defect raised during cleanup.
- Implemented types
Constructors
- CompositeDefect({required Object primary, required StackTrace primaryStackTrace, required Object secondary, required StackTrace secondaryStackTrace})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- primary → Object
-
final
- primaryStackTrace → StackTrace
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondary → Object
-
final
- secondaryStackTrace → StackTrace
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited