DuplicateServiceBindingException class final

Thrown when a Module contains more than one binding for the same service.

Implemented types

Constructors

DuplicateServiceBindingException({required Type serviceType, String? key})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceType Type
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited