EffectViewModel class abstract
Optional MVVM base class with concise, automatically disposed command creation.
Existing ViewModel bases can instead use EffectCommandOwner directly.
- Inheritance
-
- Object
- ChangeNotifier
- EffectViewModel
- Mixed-in types
Constructors
- EffectViewModel(EffectCommands commands)
Properties
- commands → EffectCommands
-
The scoped factory supplied by
BuildContext.effectCommands.final - hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
command<
A extends Object, E extends Object> (Effect< A, E> action(), {EffectCommandConcurrency concurrency = EffectCommandConcurrency.drop, bool keepPreviousData = true, String? debugLabel, VoidCallback? onCancel, EffectCommandStateObserver<A, E> ? stateObserver}) → EffectCommand0<A, E> - Create and own a command without input.
-
commandWithInput<
I, A extends Object, E extends Object> (Effect< A, E> action(I input), {EffectCommandConcurrency concurrency = EffectCommandConcurrency.drop, bool keepPreviousData = true, String? debugLabel, VoidCallback? onCancel, EffectCommandStateObserver<A, E> ? stateObserver}) → EffectCommand<I, A, E> - Create and own a command with one typed input.
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
ownCommand<
T extends EffectCommandDisposable> (T command) → T -
Register
commandfor automatic disposal with this ViewModel.inherited -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited