EffectCommandPolicyProbeExpectationException class final

Implemented types

Constructors

EffectCommandPolicyProbeExpectationException({required List<CommandPolicyDecision> expected, required List<CommandPolicyDecision> actual})
const

Properties

actual List<CommandPolicyDecision>
final
expected List<CommandPolicyDecision>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited