EffectCommandProbeExpectationException class final
Raised when a probe state sequence differs from the expectation.
- Implemented types
Constructors
-
EffectCommandProbeExpectationException({required List<
Type> expected, required List<Type> actual}) -
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited