ResolverBackendContractCase enum

Behavioral scenarios shared by ResolverBackend implementations.

Inheritance
Available extensions

Values

factoryCreatesFreshInstances → const ResolverBackendContractCase
lazySingletonIsLazyAndStable → const ResolverBackendContractCase
singletonActivatesEagerlyOnce → const ResolverBackendContractCase
instancePreservesIdentity → const ResolverBackendContractCase
keyedAndUnkeyedServicesRemainIsolated → const ResolverBackendContractCase
constructorInjectionResolvesDependencies → const ResolverBackendContractCase
missingDependencyFails → const ResolverBackendContractCase
circularDependencyFails → const ResolverBackendContractCase
duplicateRegistrationFails → const ResolverBackendContractCase
commitIsIdempotent → const ResolverBackendContractCase
activateIsIdempotent → const ResolverBackendContractCase
constructorRegistrationAfterCommitFails → const ResolverBackendContractCase
instanceRegistrationAfterCommitWorks → const ResolverBackendContractCase
constructorDefectsArePreserved → const ResolverBackendContractCase
partialRuntimeStartupFailureReleasesResources → const ResolverBackendContractCase
closeIsIdempotent → const ResolverBackendContractCase
resolveAfterCloseFails → const ResolverBackendContractCase
instantiatedServicesAreDisposed → const ResolverBackendContractCase
executionOverlayIsIsolated → const ResolverBackendContractCase

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ResolverBackendContractCase>
A constant List of the values in this enum, in order of their declaration.