ResolverBackendContractReport class final

Complete compatibility report for one backend implementation.

Constructors

ResolverBackendContractReport({required Type backendType, required Iterable<ResolverBackendContractResult> results})

Properties

backendType Type
final
failures Iterable<ResolverBackendContractResult>
no setter
hashCode int
The hash code for this object.
no setterinherited
passed bool
no setter
results List<ResolverBackendContractResult>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipped Iterable<ResolverBackendContractResult>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resultFor(ResolverBackendContractCase scenario) ResolverBackendContractResult
throwIfFailed() → void
Throw one aggregate exception when any required scenario failed.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited