ResolverBackendContractResult class final

Result of one backend compatibility scenario.

Constructors

ResolverBackendContractResult({required ResolverBackendContractCase scenario, required Duration duration, required Object? error, required StackTrace? stackTrace, required bool skipped, required String? skipReason})
const

Properties

duration Duration
final
error Object?
final
failed bool
no setter
hashCode int
The hash code for this object.
no setterinherited
passed bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scenario ResolverBackendContractCase
final
skipped bool
final
skipReason String?
final
stackTrace StackTrace?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited