ResolverBackendContractViolation class final

One failed contract assertion.

Implemented types

Constructors

ResolverBackendContractViolation({required ResolverBackendContractCase scenario, required String message, Object? cause})
const

Properties

cause Object?
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scenario ResolverBackendContractCase
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited