instantiate property
Resolve or otherwise instantiate the service instrumented by this fixture.
Implementation
final Object Function() instantiate;
Resolve or otherwise instantiate the service instrumented by this fixture.
final Object Function() instantiate;