isCompleted property
bool
get
isCompleted
Whether this gate was completed successfully or with an error.
Implementation
bool get isCompleted => _completer.isCompleted;
Whether this gate was completed successfully or with an error.
bool get isCompleted => _completer.isCompleted;