TestSignal class final

A deterministic signal for tests that only need to release a wait point.

Constructors

TestSignal()

Properties

hashCode int
The hash code for this object.
no setterinherited
isSignalled bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wait Future<void>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signal() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited