CleanupFailureDiagnostic class final
Describes a cleanup failure reported after an Effect outcome was known.
Constructors
-
CleanupFailureDiagnostic({required Exit<
Object, Object> outcome, required ScopeReleaseException error, required int executionId, String? executionLabel}) -
const
Properties
- error → ScopeReleaseException
-
The scoped cleanup failures raised while closing the outcome's Scope.
final
- executionId → int
-
A monotonically increasing execution ID within a Runtime.
final
- executionLabel → String?
-
A caller-provided label for the execution, when available.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
outcome
→ Exit<
Object, Object> -
The success, typed failure, defect, or interruption being cleaned up.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited