pendingCount property
int
get
pendingCount
Caller-visible executions that have not completed plus queued invocations.
Interrupted physical work can remain owned by the Runtime after it leaves this count. EffectCommandConcurrency.latest can also have stale physical executions that no longer own visible Command state.
Implementation
int get pendingCount => _pendingCompletions.length + _queue.length;