EffectCommandSelector<A extends Object, E extends Object, S> class
final
Rebuilds only when a selected Command value changes.
The default constructor selects from EffectCommandState. Use
EffectCommandSelector.snapshot for queue/pending counts or the
latest Exit. Default equality uses Dart ==; collections normally
need a custom equals callback.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- EffectCommandSelector
Constructors
-
EffectCommandSelector({required ValueListenable<
EffectCommandState< command, required EffectCommandStateSelector<A, E> >A, E, S> selector, required EffectCommandSelectedWidgetBuilder<S> builder, EffectCommandSelectionEquals<S> ? equals, Widget? child, Key? key}) -
const
-
EffectCommandSelector.snapshot({required EffectCommandBase<
A, E> command, required EffectCommandSnapshotSelector<A, E, S> selector, required EffectCommandSelectedWidgetBuilder<S> builder, EffectCommandSelectionEquals<S> ? equals, Widget? child, Key? key}) -
const
Properties
-
builder
→ EffectCommandSelectedWidgetBuilder<
S> -
final
- child → Widget?
-
final
-
equals
→ EffectCommandSelectionEquals<
S> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< EffectCommandSelector< A, E, S> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited