EffectCommandSuccess<A extends Object, E extends Object> class
final
The Effect completed successfully.
- Inheritance
-
- Object
- EffectCommandState<
A, E> - EffectCommandSuccess
Properties
- completedAt → DateTime
-
final
- dataOrNull → A?
-
The latest successful value visible from this state, when available.
no setterinherited
- defectOrNull → Object?
-
The unexpected defect visible from this state, when available.
no setterinherited
- defectStackTraceOrNull → StackTrace?
-
The defect stack trace visible from this state, when available.
no setterinherited
- errorOrNull → E?
-
The expected, typed failure visible from this state, when available.
no setterinherited
- executionId → int
-
Identifies the execution that produced this state.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDefect → bool
-
no setterinherited
- isFailure → bool
-
no setterinherited
- isIdle → bool
-
no setterinherited
- isInterrupted → bool
-
no setterinherited
- isRunning → bool
-
no setterinherited
- isSuccess → bool
-
no setterinherited
- isTerminal → bool
-
no setterinherited
- previousOrNull → A?
-
Previous successful data retained by this state, when available.
no setterinherited
- revision → int
-
Monotonically increasing visible-state revision.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → A
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited