EffectTransformOps<A extends Object, E extends Object> extension
Transformations available on every Effect.
- on
-
- Effect<
A, E>
- Effect<
Methods
-
asUnit(
) → Effect< Unit, E> -
Available on Effect<
Discard the success value while preserving the typed failure.A, E> , provided by the EffectTransformOps extension -
catchAll<
F extends Object> (Effect< A, F> recover(E error)) → Effect<A, F> -
Available on Effect<
Recover from every typed failure with another Effect.A, E> , provided by the EffectTransformOps extension -
either(
) → Effect< ResultDart< A, E> , Never> -
Available on Effect<
Turn the typed failure channel into a successful Result value.A, E> , provided by the EffectTransformOps extension -
flatMap<
B extends Object> (Effect< B, E> next(A value)) → Effect<B, E> -
Available on Effect<
Sequence another Effect that uses this Effect's successful value.A, E> , provided by the EffectTransformOps extension -
map<
B extends Object> (B transform(A value)) → Effect< B, E> -
Available on Effect<
Transform the successful value.A, E> , provided by the EffectTransformOps extension -
mapError<
F extends Object> (F transform(E error)) → Effect< A, F> -
Available on Effect<
Transform the typed failure.A, E> , provided by the EffectTransformOps extension -
provide<
T extends Object> (T instance, {ServiceKey< T> ? key}) → Effect<A, E> -
Available on Effect<
Run this Effect with a local service override.A, E> , provided by the EffectTransformOps extension -
tap(
FutureOr< void> inspect(A value)) → Effect<A, E> -
Available on Effect<
Run an observation after success without changing the value.A, E> , provided by the EffectTransformOps extension -
tapError(
FutureOr< void> inspect(E error)) → Effect<A, E> -
Available on Effect<
Run an observation after a typed failure without changing the failure.A, E> , provided by the EffectTransformOps extension -
timeout(
Duration duration, {required E onTimeout()}) → Effect< A, E> -
Available on Effect<
Fail withA, E> , provided by the EffectTransformOps extensiononTimeoutwhen this Effect does not finish in time. -
withLocal<
T extends Object> (EffectLocal< T> local, T value) → Effect<A, E> -
Available on Effect<
Run this Effect with a locally overridden EffectLocal value.A, E> , provided by the EffectTransformOps extension -
withLocals(
Iterable< EffectLocalBinding> bindings) → Effect<A, E> -
Available on Effect<
Apply a heterogeneous batch of typed EffectLocal values.A, E> , provided by the EffectTransformOps extension