ExitSuccess<A extends Object, E extends Object> class
final
An Effect completed successfully.
Constructors
- ExitSuccess(A value)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDefect → bool
-
no setterinherited
- isFailure → bool
-
no setterinherited
- isInterrupted → bool
-
no setterinherited
- isSuccess → bool
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → A
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited