Result<S extends Object> typedef
Result<S extends Object> = ResultDart<S, Exception>
A typedef for a Result that simplifies the usage of ResultDart
with Exception as the default failure type.
This is used to represent operations that can succeed with a
value of type S
or fail with an Exception.
Implementation
typedef Result<S extends Object> = ResultDart<S, Exception>;