EffectCommandPolicyProbe class final
Records EffectCommandPolicyEvent values in delivery order.
Pass call to EffectCommands(policyObserver: ...), a provider/bootstrap
policy observer, or one Command's policyObserver argument.
Constructors
Properties
-
events
→ List<
EffectCommandPolicyEvent> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
EffectCommandPolicyEvent event) → void -
clear(
) → void -
expectDecisions(
Iterable< CommandPolicyDecision> expected) → void - Verify the exact policy-decision sequence without depending on a matcher library.
-
lastWhereDecision(
CommandPolicyDecision decision) → EffectCommandPolicyEvent? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
whereDecision(
CommandPolicyDecision decision) → Iterable< EffectCommandPolicyEvent>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited