ResolverBackendContractException class final
Aggregate failure raised by verifyResolverBackendContract.
- Implemented types
Constructors
-
ResolverBackendContractException({required Type backendType, required Iterable<
ResolverBackendContractResult> failures})
Properties
- backendType → Type
-
final
-
failures
→ List<
ResolverBackendContractResult> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited