ResolverBackendDisposalProbe class final
Optional fixture used to prove that backend-owned instantiated services are disposed when the backend closes.
The public ResolverBackend API intentionally does not prescribe a disposal callback registration mechanism. Backend authors can expose their native mechanism through this probe while every other scenario remains portable.
Constructors
- ResolverBackendDisposalProbe({required ResolverBackend backend, required Object instantiate(), required bool wasDisposed()})
-
const
Properties
- backend → ResolverBackend
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- instantiate → Object Function()
-
Resolve or otherwise instantiate the service instrumented by this fixture.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wasDisposed → bool Function()
-
Return whether the backend's native disposal callback was invoked.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited